@@ -1,2 +1,2 @@
 #' @importFrom utils globalVariables
-utils::globalVariables("rss_table")
+utils::globalVariables("package_rss")
